summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMarius Bakke <mbakke@fastmail.com>2020-01-20 01:57:06 +0100
committerMarius Bakke <mbakke@fastmail.com>2020-01-20 21:53:52 +0100
commit43987c977c5c83a2980c8a07fd07061620e53ac1 (patch)
tree9a5655350bb5ddd6cd095769faf9a814d7f90698
parent37f44547343ab3d9baf5115b1d8c50a8591c4056 (diff)
downloadpatches-43987c977c5c83a2980c8a07fd07061620e53ac1.tar
patches-43987c977c5c83a2980c8a07fd07061620e53ac1.tar.gz
gnu: mailutils: Update to 3.8.
* gnu/packages/mail.scm (mailutils): Update to 3.8. [arguments]: Adjust substitutions.
-rw-r--r--gnu/packages/mail.scm8
1 files changed, 4 insertions, 4 deletions
diff --git a/gnu/packages/mail.scm b/gnu/packages/mail.scm
index 168e626d7e..67afea68fb 100644
--- a/gnu/packages/mail.scm
+++ b/gnu/packages/mail.scm
@@ -141,14 +141,14 @@
(define-public mailutils
(package
(name "mailutils")
- (version "3.7")
+ (version "3.8")
(source (origin
(method url-fetch)
(uri (string-append "mirror://gnu/mailutils/mailutils-"
version ".tar.xz"))
(sha256
(base32
- "1gwajsl39f1dkzrjld0dm9px8hrj7l7rwzazz00h5rwghk9mhwhq"))))
+ "1wkn9ch664477r4d8jk9153w5msljsbj99907k7zgzpmywbs6ba7"))))
(build-system gnu-build-system)
(arguments
'(#:phases
@@ -160,10 +160,10 @@
(("/bin/cat")
(which "cat")))
;; Tests try to invoke 'maidag' such that it looks up the
;; 'root' user, which does not exist in the build
;; environment.
- (substitute* "maidag/tests/testsuite"
+ (substitute* "mda/tests/testsuite"
(("root <") "nobody <")
(("spool/root") "spool/nobody")
(("root@localhost") "nobody@localhost"))
@@ -160,10 +160,10 @@
(("/bin/cat")
(which "cat")))
- ;; Tests try to invoke 'maidag' such that it looks up the
+ ;; Tests try to invoke 'mda' such that it looks up the
;; 'root' user, which does not exist in the build
;; environment.